%global systemd 1
%global	sysvinit 0
%global systemdsysv 0

%bcond_with xmlrpc

Summary:  Certificate status monitor and PKI enrollment client
Name:     certmonger
Version:  0.79.17
Release:  6%{?dist}
License:  GPLv3+
URL:      http://pagure.io/certmonger/
Source0:  https://pagure.io/certmonger/archive/%{version}/certmonger-%{version}.tar.gz

BuildRequires:  autoconf automake gcc
BuildRequires:  gettext-devel openldap-devel krb5-devel libidn2-devel
BuildRequires:  dbus-devel, nspr-devel, nss-devel, openssl-devel
BuildRequires:  libuuid-devel libtalloc-devel, libtevent-devel
BuildRequires:  libcurl-devel libxml2-devel jansson-devel diffutils expect
BuildRequires:  nss-tools openssl python3-dbus popt-devel
BuildRequires:  /usr/bin/dbus-launch /usr/bin/which
BuildRequires:  /usr/bin/dos2unix /usr/bin/unix2dos
%if %{with xmlrpc}
BuildRequires:  xmlrpc-c-devel
%endif
Requires: dbus
Requires(post): %{_bindir}/dbus-send

%if %{systemd}
BuildRequires:  systemd-units
BuildRequires:  make
Requires(post): systemd-units
Requires(preun):  systemd-units, dbus, sed
Requires(postun): systemd-units
%endif

%if %{systemdsysv}
Requires(post): systemd-sysv
%global systemdsysvsave \
%{_bindir}/systemd-sysv-convert --save certmonger >/dev/null 2>&1 ||:
%else
%global systemdsysvsave %{nil}
%endif

%if %{sysvinit}
Requires(post):   /sbin/chkconfig, /sbin/service
Requires(preun):  /sbin/chkconfig, /sbin/service, dbus, sed
%endif

%description
Certmonger provides a service that primarily concerned with getting your system enrolled 
with a certificate authority (CA) and keeping it enrolled.

%prep
%autosetup -p1 -n certmonger-%{version}

sed -i 's,^# chkconfig: - ,# chkconfig: 345 ,g' sysvinit/certmonger.in

%build
autoreconf -fi
%configure \
%if %{systemd}
	--enable-systemd \
%endif
%if %{sysvinit}
	--enable-sysvinit=%{_initddir} \
%endif
%if %{with xmlrpc}
    --with-xmlrpc \
%endif
	--enable-tmpfiles \
	--with-homedir=/run/certmonger \
	--disable-dsa \
	--with-tmpdir=/run/certmonger --enable-pie --enable-now

%if %{with xmlrpc}
%make_build XMLRPC_LIBS="-lxmlrpc_client -lxmlrpc_util -lxmlrpc"
%else
%make_build
%endif

%install
rm -rf %{buildroot}
%make_install
mkdir -p %{buildroot}/%{_localstatedir}/lib/certmonger/{cas,requests}
install -m755 -d %{buildroot}/run/certmonger

%{find_lang} %{name}

%check
make check

%post
if test $1 -eq 1 ; then
	%{_bindir}/dbus-send --system --type=method_call --dest=org.freedesktop.DBus / org.freedesktop.DBus.ReloadConfig 2>&1 || :
fi
%if %{without xmlrpc}
if test $1 -gt 1 ; then
    %{_bindir}/getcert remove-ca -c certmaster 2>&1 || :
fi
%endif
%if %{systemd}
if test $1 -eq 1 ; then
	/bin/systemctl daemon-reload >/dev/null 2>&1 || :
fi
%endif
%if %{sysvinit}
/sbin/chkconfig --add certmonger
%endif

%postun
%if %{systemd}
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
	/bin/systemctl try-restart certmonger.service >/dev/null 2>&1 || :
fi
%endif
%if %{sysvinit}
if test $1 -gt 0 ; then
	/sbin/service certmonger condrestart 2>&1 > /dev/null
fi
%endif
exit 0

%preun
%if %{systemd}
if test $1 -eq 0 ; then
	/bin/systemctl --no-reload disable certmonger.service > /dev/null 2>&1 || :
	/bin/systemctl stop certmonger.service > /dev/null 2>&1 || :
fi
%endif
%if %{sysvinit}
if test $1 -eq 0 ; then
	/sbin/service certmonger stop 2>&1 > /dev/null
	/sbin/chkconfig --del certmonger
fi
%endif
exit 0

%files -f %{name}.lang
%license LICENSE
%doc README.md STATUS doc/*.txt
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/*
%dir %{_sysconfdir}/certmonger
%config(noreplace) %{_sysconfdir}/certmonger/certmonger.conf
%attr(0644,root,root) %config(noreplace) %{_tmpfilesdir}/certmonger.conf
%dir /run/certmonger
%{_bindir}/*
%{_sbindir}/certmonger
%{_libexecdir}/%{name}
%{_localstatedir}/lib/certmonger
%if %{sysvinit}
%{_initddir}/certmonger
%endif
%if %{systemd}
%{_unitdir}/*
%{_datadir}/dbus-1/system-services/*
%endif
%{_datadir}/dbus-1/services/*
%{_mandir}/man*/*

%changelog
* Mon Sep 09 2024 Rebuild Robot <rebot@opencloudos.org> - 0.79.17-6
- [Type] other
- [DESC] Rebuilt for systemd

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.79.17-5
- Rebuilt for loongarch release

* Tue Mar 19 2024 Rebuild Robot <rebot@opencloudos.org> - 0.79.17-4
- Rebuilt for jansson

* Thu Oct 12 2023 Miaojun Dong <zoedong@tencent.com> - 0.79.17-3
- Rebuild for curl-8.4.0

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.79.17-2
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Jun 21 2023 kianli <kianli@tencent.com> - 0.79.17-1
- Upgrade to 0.79.17 and update Source0

* Fri May 19 2023 Wang Guodong <gordonwwang@tencent.com> - 0.79.16-4
- update source.

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.79.16-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.79.16-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Mar 10 2023 Wang Guodong <gordonwwang@tencent.com> - 0.79.16-1
- package init.
